#!/bin/sh

#######################################
##
## show opengate status for MRTG
##
##   1 line : IPv6 Users
##   2 line : Total Users
##   3 line : uptime
##   4 line : comment for data
##
##
#######################################


LANG=C
COLUMNS=256

export LANG
export COLUMNS

tmp_all="/tmp/og_count_all.tmp"
tmp_6="/tmp/og_count_6.tmp"

process="opengatesrv.cgi"


######################################################

ps ax | grep $process  | grep -v "grep $process" > $tmp_all

COUNT=`wc -l $tmp_all | awk '{print $1}'`

grep "(useIPv6)" $tmp_all > $tmp_6

COUNT6=`wc -l $tmp_6 | awk '{print $1}'`

UPTIME=`uptime | awk '{print $3$4}' | sed -e "s/,//g"`

rm $tmp_all
rm $tmp_6

echo "Content-type: text/plain; charset=iso-8859-1"
echo

echo "$COUNT6"
echo "$COUNT"
echo "$UPTIME"
echo "Opengate User Counter"
